@@ -128,6 +128,7 @@ void internal_clock_toggled(GtkWidget *togglebutton, gpointer data)
 	} else if (!strcmp(what, "SPDIF")) {
 		internal_clock_set(13);
 	} else if (!strcmp(what, "WordClock")) {
+		internal_clock_set(13); // 13 should be considered '!internal'
 		master_clock_word_select(1);
 	} else {
 		g_print("internal_clock_toggled: %s ???\n", what);
@@ -162,15 +163,15 @@ gint master_clock_status_timeout_callback(gpointer data)
 	snd_ctl_elem_value_t *sw;
 	int err;
 	
-	if (card_eeprom.subvendor != ICE1712_SUBDEVICE_DELTA1010)
+	if (card_eeprom.subvendor != ICE1712_SUBDEVICE_DELTA1010 && card_eeprom.subvendor != ICE1712_SUBDEVICE_DELTA1010LT)
 		return FALSE;
 	snd_ctl_elem_value_alloca(&sw);
-	snd_ctl_elem_value_set_interface(sw, SND_CTL_ELEM_IFACE_PCM);
+	snd_ctl_elem_value_set_interface(sw, SND_CTL_ELEM_IFACE_MIXER);
 	snd_ctl_elem_value_set_name(sw, "Word Clock Status");
 	if ((err = snd_ctl_elem_read(ctl, sw)) < 0)
 		g_print("Unable to determine word clock status: %s\n", snd_strerror(err));
 	gtk_label_set_text(GTK_LABEL(hw_master_clock_status_label),
-			   snd_ctl_elem_value_get_boolean(sw, 0) ? "Locked" : "No signal");
+			   snd_ctl_elem_value_get_boolean(sw, 0) ? "No signal" : "Locked");
 	return TRUE;
 }
 
@@ -605,17 +606,30 @@ void spdif_output_toggled(GtkWidget *togglebutton, gpointer data)
 void spdif_input_update(void)
 {
 	int err;
-	
-	if ((card_eeprom.subvendor != ICE1712_SUBDEVICE_DELTADIO2496) && (card_eeprom.subvendor != ICE1712_SUBDEVICE_DMX6FIRE))
+	int digoptical = FALSE;
+	int diginternal = FALSE;
+
+	if ((card_eeprom.subvendor != ICE1712_SUBDEVICE_DELTADIO2496) &&
+	    ! card_is_dmx6fire)
 		return;
 	if ((err = snd_ctl_elem_read(ctl, spdif_input)) < 0)
 		g_print("Unable to read S/PDIF input switch: %s\n", snd_strerror(err));
-	if (snd_ctl_elem_value_get_boolean(spdif_input, 0)) {
+	if (snd_ctl_elem_value_get_boolean(spdif_input, 0))
+		digoptical = TRUE;
+	if (card_is_dmx6fire) {
+        	if ((err = snd_ctl_elem_read(ctl, spdif_on_off)) < 0)
+			g_print("Unable to read S/PDIF on/off switch: %s\n", snd_strerror(err));
+	      	if (!(snd_ctl_elem_value_get_boolean(spdif_on_off, 0)))
+			diginternal = TRUE;
+	}
+	if (digoptical) {
 		toggle_set(hw_spdif_input_optical_radio, TRUE);
 	} else {
 		toggle_set(hw_spdif_input_coaxial_radio, TRUE);
 	}
-}
+	if (diginternal)
+		toggle_set(hw_spdif_switch_off_radio, TRUE);
+ }
 
 void spdif_input_toggled(GtkWidget *togglebutton, gpointer data)
 {
@@ -624,10 +638,18 @@ void spdif_input_toggled(GtkWidget *togglebutton, gpointer data)
 	
 	if (!is_active(togglebutton))
 		return;
-	if (!strcmp(str, "Optical"))
-		snd_ctl_elem_value_set_boolean(spdif_input, 0, 1);
-	else
-		snd_ctl_elem_value_set_boolean(spdif_input, 0, 0);
+	if (!strcmp(str, "Off"))
+               	snd_ctl_elem_value_set_boolean(spdif_on_off, 0, 0);
+	else {
+		snd_ctl_elem_value_set_boolean(spdif_on_off, 0, 1);
+		if (!strcmp(str, "Optical"))
+			snd_ctl_elem_value_set_boolean(spdif_input, 0, 1);
+		else
+			if (!strcmp(str, "Coaxial"))
+				snd_ctl_elem_value_set_boolean(spdif_input, 0, 0);
+	}
+	if ((err = snd_ctl_elem_write(ctl, spdif_on_off)) < 0)
+               g_print("Unable to write S/PDIF on/off switch: %s\n", snd_strerror(err));
 	if ((err = snd_ctl_elem_write(ctl, spdif_input)) < 0)
 		g_print("Unable to write S/PDIF input switch: %s\n", snd_strerror(err));
 }
@@ -636,7 +658,7 @@ void analog_input_select_update(void)
 {
 	int err, input_interface;
 
-	if (card_eeprom.subvendor != ICE1712_SUBDEVICE_DMX6FIRE)
+	if (! card_is_dmx6fire)
 		return;
 	if ((err = snd_ctl_elem_read(ctl, analog_input_select)) < 0)
 		g_print("Unable to read analog input switch: %s\n", snd_strerror(err));
@@ -664,88 +686,34 @@ void analog_input_select_set(int value)
 void analog_input_select_toggled(GtkWidget *togglebutton, gpointer data)
 {
 	char *what = (char *) data;
+       int err;
 
         if (!is_active(togglebutton))
                 return;
         if (!strcmp(what, "Internal")) {
                 analog_input_select_set(0);
+               snd_ctl_elem_value_set_boolean(breakbox_led, 0, 0);
         } else if (!strcmp(what, "Front Input")) {
                 analog_input_select_set(1);
+               snd_ctl_elem_value_set_boolean(breakbox_led, 0, 1);
         } else if (!strcmp(what, "Rear Input")) {
                 analog_input_select_set(2);
+               snd_ctl_elem_value_set_boolean(breakbox_led, 0, 0);
         } else if (!strcmp(what, "Wave Table")) {
                 analog_input_select_set(3);
+               snd_ctl_elem_value_set_boolean(breakbox_led, 0, 0);
         } else {
                 g_print("analog_input_select_toggled: %s ???\n", what);
         }
-}
-
-
-void breakbox_led_update(void)
-{
-	int err;
-
-	 if (card_eeprom.subvendor != ICE1712_SUBDEVICE_DMX6FIRE)
-		return;
-	if ((err = snd_ctl_elem_read(ctl, breakbox_led)) < 0)
-		g_print("Unable to read breakbox LED switch: %s\n", snd_strerror(err));
-	if (snd_ctl_elem_value_get_boolean(breakbox_led, 0)) {
-		 toggle_set(hw_breakbox_led_on_radio, TRUE);
-	} else {
-		 toggle_set(hw_breakbox_led_off_radio, TRUE);
-	}
-}
-
-void breakbox_led_toggled(GtkWidget *togglebutton, gpointer data)
-{
-	int err;
-		char *str = (char *)data;
-
-	 if (!is_active(togglebutton))
-		return;
-	if (!strcmp(str, "On"))
-			snd_ctl_elem_value_set_boolean(breakbox_led, 0, 1);
-	else
-			snd_ctl_elem_value_set_boolean(breakbox_led, 0, 0);
-	if ((err = snd_ctl_elem_write(ctl, breakbox_led)) < 0)
-		g_print("Unable to write breakbox LED switch: %s\n", snd_strerror(err));
-}
-
-void spdif_on_off_update(void)
-{
-        int err;
-
-        if (card_eeprom.subvendor != ICE1712_SUBDEVICE_DMX6FIRE)
-                return;
-        if ((err = snd_ctl_elem_read(ctl, spdif_on_off)) < 0)
-                g_print("Unable to read S/PDIF on/off switch: %s\n", snd_strerror(err));
-        if (snd_ctl_elem_value_get_boolean(spdif_on_off, 0)) {
-                toggle_set(hw_spdif_switch_on_radio, TRUE);
-        } else {
-                toggle_set(hw_spdif_switch_off_radio, TRUE);
-        }
-}
-
-void spdif_on_off_toggled(GtkWidget *togglebutton, gpointer data)
-{
-        int err;
-        char *str = (char *) data;
-
-        if (!is_active(togglebutton))
-                return;
-        if (!strcmp(str, "On"))
-                snd_ctl_elem_value_set_boolean(spdif_input, 0, 1);
-        else
-                snd_ctl_elem_value_set_boolean(spdif_input, 0, 0);
-        if ((err = snd_ctl_elem_write(ctl, spdif_input)) < 0)
-                g_print("Unable to write S/PDIF on/off switch: %s\n", snd_strerror(err));
+       if ((err = snd_ctl_elem_write(ctl, breakbox_led)) < 0)
+               g_print("Unable to write breakbox LED switch: %s\n", snd_strerror(err));
 }
 
 void phono_input_update(void)
 {
         int err;
 
-        if (card_eeprom.subvendor != ICE1712_SUBDEVICE_DMX6FIRE)
+        if (! card_is_dmx6fire)
                 return;
         if ((err = snd_ctl_elem_read(ctl, phono_input)) < 0)
                 g_print("Unable to read phono input switch: %s\n", snd_strerror(err));
@@ -795,7 +763,7 @@ void hardware_init(void)
 	snd_ctl_elem_value_set_interface(internal_clock_default, SND_CTL_ELEM_IFACE_MIXER);
 	snd_ctl_elem_value_set_name(internal_clock_default, "Multi Track Internal Clock Default");
 
-	snd_ctl_elem_value_set_interface(word_clock_sync, SND_CTL_ELEM_IFACE_PCM);
+	snd_ctl_elem_value_set_interface(word_clock_sync, SND_CTL_ELEM_IFACE_MIXER);
 	snd_ctl_elem_value_set_name(word_clock_sync, "Word Clock Sync");
 
 	snd_ctl_elem_value_set_interface(rate_locking, SND_CTL_ELEM_IFACE_MIXER);
@@ -807,12 +775,12 @@ void hardware_init(void)
 	snd_ctl_elem_value_set_interface(volume_rate, SND_CTL_ELEM_IFACE_MIXER);
 	snd_ctl_elem_value_set_name(volume_rate, "Multi Track Volume Rate");
 
-	if(card_eeprom.subvendor == ICE1712_SUBDEVICE_DMX6FIRE){
+	if (! card_is_dmx6fire) {
 		snd_ctl_elem_value_set_interface(spdif_input, SND_CTL_ELEM_IFACE_MIXER);
 		snd_ctl_elem_value_set_name(spdif_input, "Optical Digital Input Switch");
 	} else {
-	snd_ctl_elem_value_set_interface(spdif_input, SND_CTL_ELEM_IFACE_PCM);
-	snd_ctl_elem_value_set_name(spdif_input, "IEC958 Input Optical");
+		snd_ctl_elem_value_set_interface(spdif_input, SND_CTL_ELEM_IFACE_MIXER);
+		snd_ctl_elem_value_set_name(spdif_input, "IEC958 Input Optical");
 	}
 
 	snd_ctl_elem_value_set_interface(spdif_output, SND_CTL_ELEM_IFACE_PCM);
@@ -841,7 +809,5 @@ void hardware_postinit(void)
 	spdif_input_update();
 	spdif_output_update();
 	analog_input_select_update();
-	breakbox_led_update();
-	spdif_on_off_update();
 	phono_input_update();
 }
